@@ -260,6 +260,9 @@ typedef enum {
     ssl_grp_ffdhe_4096 = 258,
     ssl_grp_ffdhe_6144 = 259,
     ssl_grp_ffdhe_8192 = 260,
+    ssl_grp_kem_secp256r1mlkem768 = 4587,
+    ssl_grp_kem_secp384r1mlkem1024 = 4589,
+    ssl_grp_kem_mlkem768x25519 = 4588,
     ssl_grp_kem_xyber768d00 = 25497, /* draft-tls-westerbaan-xyber768d00-02 */
     ssl_grp_none = 65537,            /* special value */
     ssl_grp_ffdhe_custom = 65538     /* special value */
@@ -585,13 +588,13 @@ typedef enum {
     ssl_dhe_group_max
 } SSLDHEGroupType;
 
-/* RFC 8879: TLS Certificate Compression - 3. Negotiating Certificate Compression 
+/* RFC 8879: TLS Certificate Compression - 3. Negotiating Certificate Compression
 ** enum {
 **  zlib(1),
 **  brotli(2),
 **  zstd(3),
 **  (65535)
-** } CertificateCompressionAlgorithm; 
+** } CertificateCompressionAlgorithm;
 */
 typedef PRUint16 SSLCertificateCompressionAlgorithmID;
 
@@ -599,7 +602,11 @@ typedef struct SSLCertificateCompressionAlgorithmStr {
     SSLCertificateCompressionAlgorithmID id;
     const char* name;
     SECStatus (*encode)(const SECItem* input, SECItem* output);
-    SECStatus (*decode)(const SECItem* input, SECItem* output, size_t expectedLenDecodedCertificate);
+    /* outputLen is the length of the output buffer passed by NSS to the decode function.
+     * Decode should return an error code if the decoding fails or the output buffer is not big enough.
+     * usedLen is an outparam which indicates the number of bytes the decoder consumed from output.
+     * Note: usedLen is always <= outputLen. */
+    SECStatus (*decode)(const SECItem* input, unsigned char* output, size_t outputLen, size_t* usedLen);
 } SSLCertificateCompressionAlgorithm;
 
 #endif /* __sslt_h_ */
